@@ -25,7 +25,7 @@ except ImportError:
     import z0lib
 
 
-__version__ = "2.0.1"
+__version__ = "2.0.2"
 python_version = "%s.%s" % (sys.version_info[0], sys.version_info[1])
 
 #
@@ -43,7 +43,7 @@ REQVERSION = {
     "beautifulsoup": {"6.1": "==3.2.1"},
     "codicefiscale": {"6.1": "==0.9"},
     "coverage": {"2.7": "<5.0.0", "3.5": ">=5.0.0"},
-    "cryptography": {"6.1": ">=2.2.2"},
+    "cryptography": {"2.7": ">=2.2.2", "3.7": ">=38.0"},
     "decorator": {"6.1": "==3.4.0", "10.0": "==4.0.10"},
     "docutils": {"6.1": "==0.12", "0": "==0.14"},  # Version by test pkgs
     "ebaysdk": {"6.1": "==2.1.4"},
@@ -317,6 +317,7 @@ MANIFEST_NAMES = {
         "/--editable=git+https://github.com/apache/"
         "chemistry-cmislib.git@py3_compat#egg=cmislib"
     ),
+    "Crypto.Cipher": "pycrypto",
     "facturx": "factur-x",
     "past": "future",
     "u2flib_server": "python-u2flib-server",
